@@ -1,4 +1,3 @@
-import os
 import sys
 from io import BytesIO
 from PIL import Image, ImageFile, ImageOps, ExifTags
@@ -12,7 +11,7 @@ except ImportError:
 
 
 DEFAULT_SIZE = getattr(settings, 'DJANGORESIZED_DEFAULT_SIZE', [1920, 1080])
-DEFAULT_QUALITY = getattr(settings, 'DJANGORESIZED_DEFAULT_QUALITY', 0)
+DEFAULT_QUALITY = getattr(settings, 'DJANGORESIZED_DEFAULT_QUALITY', -1)
 DEFAULT_KEEP_META = getattr(settings, 'DJANGORESIZED_DEFAULT_KEEP_META', True)
 DEFAULT_FORCE_FORMAT = getattr(settings, 'DJANGORESIZED_DEFAULT_FORCE_FORMAT', None)
 DEFAULT_FORMAT_EXTENSIONS = getattr(settings, 'DJANGORESIZED_DEFAULT_FORMAT_EXTENSIONS', {})
@@ -46,12 +45,14 @@ def normalize_rotation(image):
     if action_nr is None:
         """ Empty orientation exif data """
         return image
-    if action_nr == 3:
+    if action_nr in (3, 4):
         image = image.rotate(180, expand=True)
-    elif action_nr == 6:
+    elif action_nr in (5, 6):
         image = image.rotate(270, expand=True)
-    elif action_nr == 8:
+    elif action_nr in (7, 8):
         image = image.rotate(90, expand=True)
+    if action_nr in (2, 4, 5, 7):
+        image = ImageOps.mirror(image)
     image.format = format
     return image
 
@@ -65,20 +66,29 @@ class ResizedImageFieldFile(ImageField.attr_class):
         if DEFAULT_NORMALIZE_ROTATION:
             img = normalize_rotation(img)
 
-        if self.field.force_format and self.field.force_format.lower() in ('jpeg', 'jpg') and img.mode != 'RGB':
+        rgb_formats = ('jpeg', 'jpg')
+        rgba_formats = ('png')
+        if self.field.force_format and self.field.force_format.lower() in rgb_formats and img.mode != 'RGB':
             img = img.convert('RGB')
+        if self.field.force_format and self.field.force_format.lower() in rgba_formats and img.mode != 'RGBA':
+            img = img.convert('RGBA')
 
+        try:
+            # Replace ANTIALIAS in PIL 9
+            resample = Image.Resampling.LANCZOS
+        except AttributeError:
+            resample = Image.ANTIALIAS
         if self.field.crop:
             thumb = ImageOps.fit(
                 img,
                 self.field.size,
-                Image.ANTIALIAS,
+                resample,
                 centering=self.get_centring()
             )
         else:
             img.thumbnail(
                 self.field.size,
-                Image.ANTIALIAS,
+                resample,
             )
             thumb = img
 
@@ -98,6 +108,9 @@ class ResizedImageFieldFile(ImageField.attr_class):
     def get_name(self, name, format):
         extensions = Image.registered_extensions()
         extensions = {v: k for k, v in extensions.items()}
+        extensions.update({
+            "PNG": ".png",  # It uses .apng otherwise
+        })
         extensions.update(DEFAULT_FORMAT_EXTENSIONS)
         if format in extensions:
             name = name.rsplit('.', 1)[0] + extensions[format]
@@ -144,19 +157,3 @@ class ResizedImageField(ImageField):
         for custom_kwargs in ['crop', 'size', 'quality', 'keep_meta', 'force_format']:
             kwargs[custom_kwargs] = getattr(self, custom_kwargs)
         return name, path, args, kwargs
-
-
-try:
-    from south.modelsinspector import add_introspection_rules
-except ImportError:
-    pass
-else:
-    rules = [
-        (
-            (ResizedImageField,),
-            [],
-            {
-            },
-        )
-    ]
-    add_introspection_rules(rules, ["^django_resized\.forms\.ResizedImageField"])
